@@ -1,11 +1,16 @@
-# shadowstep/locator/map/ui_to_dict.py
+"""Mapping from UiSelector attributes to Shadowstep dictionary format.
+
+This module provides the mapping dictionary that converts UiSelector
+attributes to their corresponding Shadowstep dictionary representation
+with appropriate value conversion functions.
+"""
 from collections.abc import Callable
 from typing import Any
 
 from shadowstep.locator.types.shadowstep_dict import ShadowstepDictAttribute
 from shadowstep.locator.types.ui_selector import UiAttribute
 
-UI_TO_SHADOWSTEP_DICT: dict[UiAttribute, Callable[[Any], dict[str, Any]]] = {
+UI_TO_SHADOWSTEP_DICT: dict[UiAttribute, Callable[[str], dict[str, Any]]] = {
     # --- text-based ---
     UiAttribute.TEXT: lambda v: {ShadowstepDictAttribute.TEXT.value: v},
     UiAttribute.TEXT_CONTAINS: lambda v: {ShadowstepDictAttribute.TEXT_CONTAINS.value: v},
